==> turbinia-20210120.2.tar.gz: turbinia-20210120.2/turbinia/jobs/docker.py <==
# -*- coding: utf-8 -*-
# Copyright 2018 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Job to execute docker-explorer, and generate new Evidence per container"""

from __future__ import unicode_literals

from turbinia.evidence import DockerContainer
from turbinia.evidence import GoogleCloudDisk
from turbinia.evidence import GoogleCloudDiskRawEmbedded
from turbinia.evidence import RawDiskPartition
from turbinia.jobs import interface
from turbinia.jobs import manager
from turbinia.workers.docker import DockerContainersEnumerationTask


class DockerContainersEnumerationJob(interface.TurbiniaJob):
  """Use docker-explorer to list all containers in a Linux docker environment"""

  # Types of evidence that this Job will process.
  evidence_input = [
      GoogleCloudDisk, GoogleCloudDiskRawEmbedded, RawDiskPartition
  ]
  evidence_output = [DockerContainer]

  NAME = 'DockerContainersEnumerationJob'

  def create_tasks(self, evidence):
    """Create task.

    Args:
      evidence: List of evidence object to process

    Returns:
        A list of tasks to schedule.
    """
    tasks = [DockerContainersEnumerationTask() for _ in evidence]
    return tasks


manager.JobsManager.RegisterJob(DockerContainersEnumerationJob)

==> turbinia-20210208.3.tar.gz: turbinia-20210208.3/turbinia/jobs/docker.py <==
# -*- coding: utf-8 -*-
# Copyright 2018 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Job to execute docker-explorer, and generate new Evidence per container"""

from __future__ import unicode_literals

from turbinia.evidence import DiskPartition
from turbinia.evidence import DockerContainer
from turbinia.jobs import interface
from turbinia.jobs import manager
from turbinia.workers.docker import DockerContainersEnumerationTask


class DockerContainersEnumerationJob(interface.TurbiniaJob):
  """Use docker-explorer to list all containers in a Linux docker environment"""

  # Types of evidence that this Job will process.
  evidence_input = [DiskPartition]
  evidence_output = [DockerContainer]

  NAME = 'DockerContainersEnumerationJob'

  def create_tasks(self, evidence):
    """Create task.

    Args:
      evidence: List of evidence object to process

    Returns:
        A list of tasks to schedule.
    """
    tasks = [DockerContainersEnumerationTask() for _ in evidence]
    return tasks


manager.JobsManager.RegisterJob(DockerContainersEnumerationJob)
